Register

Enum Register 

#[repr(u8)]
pub enum Register { A = 6, B = 1, C = 0, D = 3, E = 2, H = 5, L = 4, }
This enumerates the internal byte registers of the 8080. You can access these by indexing the State struct with them; let val = st[Register::D];

Variants



A = 6



B = 1



C = 0



D = 3



E = 2



H = 5



L = 4