pub struct Machine<H: Harness + ?Sized, C: BorrowMut<H>> { /* private fields */ }Expand description
This is the main outward-facing type for actually executing instructions. It also accepts interrupt requests, including RST instructions. It can be used as an Iterator to do processing in between operations. It also forwards the contained Harness object out to receive method requests.
Implementations
Sourceimpl<H: Harness + ?Sized, C: BorrowMut<H>> Machine<H, C>
impl<H: Harness + ?Sized, C: BorrowMut<H>> Machine<H, C>
Sourcepub fn execute(&mut self) -> Option<NonZeroU8>
pub fn execute(&mut self) -> Option<NonZeroU8>
The execute method is the heart and soul of emulation; it retrieves, decodes, and executes
one operation from the Harness address space, and updates the CPU’s internal state accordingly.
The method returns an optional non-zero 8-bit number indicating the number of CPU cycles consumed, which you can use for timing control, or no value if the chip could not proceed.
When the crate is compiled with the "open" feature, this method instead returns a Result,
which contains the same optional u8 as the regular form in its Ok option or a String
describing the failure in the Err option.
For details of the chip operation and instruction set, see the 8080 Programmer’s Manual.
Sourcepub fn interrupt(&mut self, op: Op) -> Result<bool, Error>
pub fn interrupt(&mut self, op: Op) -> Result<bool, Error>
This method submits an interrupt request containing any operation that can be contained
in one byte. If the core’s interrupts flag is reset, no action will be taken and the
method will return Ok(false). If the flag is set and the operation fits into a single
byte (a technical requirement of the original chip), it will reset the interrupts flag
(disabling interrupts until further notice; interrupt vectors should be written to set
the flag before returning) and execute the supplied instruction, then return Ok(true).
If the operation cannot fit into a single byte, the operation will return a
Err(NotUsable(_)) value containing the submitted operation and take no further action.
Sourcepub fn reset_to(&mut self, index: usize) -> Result<bool, OutOfRange>
pub fn reset_to(&mut self, index: usize) -> Result<bool, OutOfRange>
This method is a convenience shorthand for interrupt that assumes the desired
operation is a RST action, saving the address of the next instruction of the stack
and jumping to one of the addresses 0x00, 0x80, 0x10, 0x18, 0x20, 0x28, 0x30, 0x38, 0x40 or 0x48.
Sourceimpl<H: Harness + ?Sized, C: BorrowMut<H>> Machine<Rc<RefCell<(C, PhantomData<H>)>>, Rc<RefCell<(C, PhantomData<H>)>>>
Machines based on a Shared (Rc<RefCell<H>>) or Synced (Arc<Mutex<H>>) model can
provide a new Machine using the same shared Harness but a new State, crudely emulating
multiprocessing.
impl<H: Harness + ?Sized, C: BorrowMut<H>> Machine<Rc<RefCell<(C, PhantomData<H>)>>, Rc<RefCell<(C, PhantomData<H>)>>>
Machines based on a Shared (Rc<RefCell<H>>) or Synced (Arc<Mutex<H>>) model can
provide a new Machine using the same shared Harness but a new State, crudely emulating
multiprocessing.